Skip to contents

A toy dataset included with the package to illustrate usage of functions in CellTFusion. This dataset contains the output of a deconvolution run for a small subset of genes.

Usage

deconv.tuto

Format

A data frame with X rows and Y variables:

Examples

data(deconv.tuto)