Skip to contents

Fisher's exact test for score-trait association

Usage

scores.fisher.test(scores, coldata, trait, pval = 0.05)

Arguments

scores

A list whose first element is a samples x features score matrix, e.g. the output of construct_cell_groups() or compute.latent_factors(). To test a plain matrix, use scores.stat.analysis(). Continuous scores are binarised at the median into High/Low groups.

coldata

A data frame containing the clinical or experimental traits.

trait

Character. Name of the column in coldata to test with Fisher's exact test.

pval

Numeric. P-value threshold for significance (default 0.05).

Value

A list containing the significant features after Fisher test. Additionally, it saves corresponding barplot visualizations in the "Results/" folder.