Example Deconvolution Results
deconv.tuto.RdA toy dataset included with the package to illustrate usage of functions in CellTFusion. This dataset contains the output of a deconvolution run for a small subset of genes.
Examples
data(deconv.tuto)

deconv.tuto.RdA toy dataset included with the package to illustrate usage of functions in CellTFusion. This dataset contains the output of a deconvolution run for a small subset of genes.
data(deconv.tuto)