Identify hub TFs
identify_hub_TFs.RdIdentifies hub TFs per module using values of module membership and degree.
Arguments
- datExpr
A matrix of TF activity (TFs as rows and samples as columns).
- TF.network
TF network obtained from compute.WTCNA().
- MM_thresh
Threshold for module membership (e.g., 0.8).
- degree_thresh
Quantile threshold for degree (e.g., 0.9 for top 10%).
TFs with high module membership (r > MM_thresh) and among the top percentage of genes by degree (above degree_thresh quantile) are considered hub TFs.