One-way ANOVA test for multi-group comparisons
scores.anova.test.RdPerforms one-way ANOVA to test for differences in scores across multiple levels of a trait. Tukey post-hoc tests are used to identify pairwise differences and significance is visualized as annotated boxplots.
Arguments
- scores
A list, NMF output from
compute.latent_factors(), or a score matrix. When a list, the first element must be a samples x features score matrix.- coldata
A data frame containing sample annotations including the grouping variable.
- trait
Character. Name of the column in
coldataused for the grouping variable.- pval
Numeric. P-value threshold for significance (default = 0.05).