Fisher's exact test for score-trait association
scores.fisher.test.RdFisher's exact test for score-trait association
Arguments
- scores
A list whose first element is a samples x features score matrix, e.g. the output of
construct_cell_groups()orcompute.latent_factors(). To test a plain matrix, usescores.stat.analysis(). Continuous scores are binarised at the median into High/Low groups.- coldata
A data frame containing the clinical or experimental traits.
- trait
Character. Name of the column in
coldatato test with Fisher's exact test.- pval
Numeric. P-value threshold for significance (default 0.05).